// INTERACTIVE TAKE OFF YOUR SHOES SIGN CODE
//
// 11/3/21

//This code uses an ultrasonic sensor and motion detector to move a positional 
//servo motor and a continuous servo motor for the "Interactive (and slightly 
// passive aggressive" Take-Off-Your-Shoes Sign" project. 

//PART 1:
//When the ultrasonic sensor detects the front door within a defined  distance 
//threshold the positional servo motor rotates 90 degrees (this rotates the 
// "take-off-your-shoes" sign 90 degrees off of the wall to face the user.

//PART 2:
//When the motion sensor detects the movement of someone placing their shoes on 
//the shoe rack, a continious servo motor to rotates at a defined speed for a 
//short period of time, effectively rotating approximately 180 degrees. This rotation
//spins and displays a "thank you" sign.


#include <Servo.h>


/////inputs for ultrasonic sensor & servoMotor1 (a positional servo motor) //////

int triggerPin=3; //output signal pin for ultrasonic sensor
int echoPin=2; //input signal pin for ultrasonic sensor
int servoPin1=11; //setting servoMotor1 to pin 11
int distance_threshold; //target distance threshold 
bool signOpen =false; //sign is initially closed
bool motionDetected =false; //no motion is initially detected
Servo servoMotor1; //setting up servoMotor1 which will rotate 90 degrees due to ultrasonic sensor


/////inputs for motion sensor & servoMotor2 (a continuous servo motor) //////

int motionSensor_state=0; //creating variable to store current state of motion sensor
int servoPin2=10; //setting servoMotor2 to pin 12
Servo servoMotor2; //setting up servoMotor2 which will rotate continuously for a set amount of time





void setup()
{
 Serial.begin(9600); //defining rate of communication from Arduino to Serial Monitor

 //set up for ultrasonic sensor & servoMotor1
 pinMode(servoPin1, OUTPUT);// setting servoMotor1 pin as an output
 servoMotor1.attach(servoPin1); //attaching servoPin1 to servoMotor1
 servoMotor1.write(180); //initial position for servoMotor1
  
 //set up for motion sensor & servoMotor2
  pinMode(7, INPUT); //setting input signal for motion sensor to be pin 7
  pinMode(servoPin2, OUTPUT); // setting Servo_2 pin as an output
  servoMotor2.attach(servoPin2); //attaching servoPin2 to servoMotor2
  servoMotor2.write(90); //initial speed of servoMotor2 is 0
  
}

void loop()
{
   
//loop for ultrasonic sensor & servoMotor1
distance_threshold= 45; //[cm] setting threshold distance to activate servo motor
  
//function that measures distance reported by ultrasonic sensor in cm
long duration, inches, cm;
  {
pinMode(triggerPin, OUTPUT); // clearing triggerPin
digitalWrite(triggerPin, LOW); 
delayMicroseconds(2); // wait for 2 microseconds
digitalWrite(triggerPin, HIGH); //sets triggerPin to HIGH for 5 microseconds
delayMicroseconds(5); // wait for 5 microseconds
digitalWrite(triggerPin, LOW);

//reads the echoPin and returns sound wave travel time
pinMode(echoPin, INPUT);  //sets echoPin as input
duration = pulseIn(echoPin, HIGH); //returns length of pulse in microseconds

//convert the time into a distance
cm = microsecondsToCentimeters(duration);
  

//prints distance detected by ultrasonic sensor in [cm]
Serial.print(cm);
Serial.print("cm");
Serial.println();
  
delay(100); //delay 100 microseconds
  
  
}

 
 //ultrasonic sensor & servoMotor1
 //


  //if distance detected by ultrasonic sensor is less than threshold distance,
  //servoMotor1 rotates 90 degrees at 5 degree increments
  if (cm<distance_threshold && signOpen==false){ 
    servoMotor1.write(180); 
    delay(100); //delays 100 microseconds
    servoMotor1.write(175); //moves servoMotor1 to position 175
    
    delay(100); //delays 100 microseconds
    servoMotor1.write(170); //moves servoMotor1 to position 170
    
    delay(100); //delays 100 microseconds
    servoMotor1.write(165); //moves servoMotor1 to position 165
    
    delay(100); //delays 100 microseconds
    servoMotor1.write(160); //moves servoMotor1 to position 160
    
    delay(100); //delays 100 microseconds
    servoMotor1.write(155); //moves servoMotor1 to position 155
    
    delay(100); //delays 100 microseconds
    servoMotor1.write(150); //moves servoMotor1 to position 150
    
    delay(100); //delays 100 microseconds
    servoMotor1.write(145); //moves servoMotor1 to position 145
    
    delay(100); //delays 100 microseconds
    servoMotor1.write(140); //moves servoMotor1 to position 140
    
    delay(100); //delays 100 microseconds
    servoMotor1.write(135); //moves servoMotor1 to position 135
    
    delay(100); //delays 100 microseconds
    servoMotor1.write(130); //moves servoMotor1 to position 130
    
    delay(100); //delays 100 microseconds
    servoMotor1.write(125); //moves servoMotor1 to position 125
    
    delay(100); //delays 100 microseconds
    servoMotor1.write(120); //moves servoMotor1 to position 120
    
    delay(100); //delays 100 microseconds
    servoMotor1.write(115); //moves servoMotor1 to position 115

    delay(100); //delays 100 microseconds
    servoMotor1.write(110); //moves servoMotor1 to position 110

    delay(100); //delays 100 microseconds
    servoMotor1.write(105); //moves servoMotor1 to position 105

    delay(100); //delays 100 microseconds
    servoMotor1.write(100); //moves servoMotor1 to position 100

    delay(100); //delays 100 microseconds
    servoMotor1.write(95); //moves servoMotor1 to position 95

    
    delay(100); //delays 100 microseconds
    servoMotor1.write(90); //moves servoMotor1 to position 90
    

    

    delay(10000); //starts timer for 10 seconds
    
    
//servoMotor1 rotates back -90 degrees to its original position on the wall
    
    servoMotor1.write(90); //moves servoMotor1 to position 90
    delay(100); //delays 100 microseconds
    
    servoMotor1.write(95); //moves servoMotor1 to position 95
    delay(100); //delays 100 microseconds
    
    servoMotor1.write(100); //moves servoMotor1 to position 100
    delay(100); //delays 100 microseconds
    
    servoMotor1.write(105); //moves servoMotor1 to position 105
    delay(100); //delays 100 microseconds
    
    servoMotor1.write(110); //moves servoMotor1 to position 110
    delay(100); //delays 100 microseconds
    
    servoMotor1.write(115); //moves servoMotor1 to position 115
    delay(100); //delays 100 microseconds
    
    servoMotor1.write(120); //moves servoMotor1 to position 120
    delay(100); //delays 100 microseconds
    
    servoMotor1.write(125); //moves servoMotor1 to position 125
    delay(100); //delays 100 microseconds
    
    servoMotor1.write(130); //moves servoMotor1 to position 130
    delay(100); //delays 100 microseconds
    
    servoMotor1.write(135); //moves servoMotor1 to position 135
    delay(100); //delays 100 microseconds
    
    servoMotor1.write(140); //moves servoMotor1 to position 140
    delay(100); //delays 100 microseconds
    
    servoMotor1.write(145); //moves servoMotor1 to position 145
    delay(100); //delays 100 microseconds
    
    servoMotor1.write(150); //moves servoMotor1 to position 150
    delay(100); //delays 100 microseconds
    
    servoMotor1.write(155); //moves servoMotor1 to position 155
    delay(100); //delays 100 microseconds
    
    servoMotor1.write(160); //moves servoMotor1 to position 160
    delay(100); //delays 100 microseconds
    
    servoMotor1.write(165); //moves servoMotor1 to position 165
    delay(100); //delays 100 microseconds
    
    servoMotor1.write(170); //moves servoMotor1 to position 170
    delay(100); //delays 100 microseconds
    
    servoMotor1.write(175); //moves servoMotor1 to position 175
    delay(100); //delays 100 microseconds
    
    servoMotor1.write(180); //moves servoMotor1 to position 180
    delay(100); //delays 100 microseconds
   
    

    signOpen=true; //sign has been opened, exit if statement
    
    //displays that sign is open in Serial Monitor
    Serial.print(signOpen);
    Serial.print("signOpen");
    Serial.println();
    
    delay(100); //wait for 100 milliseconds
    
  }
  

  
  
 //motion sensor & servoMotor2
 
  motionSensor_state= digitalRead(7); //reads the state of the sensor digital input
  
  //if the motion sensor detects movement of someone placing shoes on shoe rack,
  //indicates to servoMotor2 to rotate 180 degrees to display "thank you" sign
  
  if (motionSensor_state==HIGH && motionDetected==false) {
    servoMotor2.write(80); //rotates servo motor at speed 80
    delay(1800); //starts timer for 1.800 seconds (the time it takes to rotate ~180 degrees at speed 80 (determined by testing)
    servoMotor2.write(90); //after 1.8 second delay, servoMotor2 stops rotating
    motionDetected=true; //motion has been deteced, exit if loop

    //displays that motion has been detected in Serial Monitor
    Serial.print(motionDetected);
    Serial.print("motionDetected");
    Serial.println();
    delay(100);
  }  

  
  delay(100); //wait for 100 milliseconds
    
 
   
   
  
  }

//converting microseconds to centimeters for ultrasonic sensor

long microsecondsToCentimeters(long microseconds) {
  
  //speed of sound is 340 m/s or 29 microseconds per cm.
  //the ping travels out and back, so to the find distance of the
  //object we take half of the distance traveled
  return microseconds / 29 / 2;
}
 
